@@ -17,13 +17,12 @@ from sqlalchemy.sql.schema import Column, Table
 from sqlalchemy.sql.selectable import Select, Subquery
 from sqlalchemy.types import Boolean
 
-from codebase_ops import get_log_file_path
 from cyclops.utils.common import to_list, to_list_optional
 from cyclops.utils.log import setup_logging
 
 # Logging.
 LOGGER = logging.getLogger(__name__)
-setup_logging(log_path=get_log_file_path(), print_level="INFO", logger=LOGGER)
+setup_logging(print_level="INFO", logger=LOGGER)
 
 COLUMN_OBJECTS = [Column, ColumnClause]
 
